==> icedove-dispmua_1.6.3.orig.tar.gz: icedove-dispmua-1.6.3/chrome/content/data-63.js <==
dispMUA.arDispMUAAllocation["c"] =
{
  "cart managment system at http://www.linuxcenter.ru" : [ "linuxcenter_ru.png" , "http://www.linuxcenter.ru/" ] ,
  "correo electrónico de internet de microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "cart managment system at http://linuxcenter.ru" : [ "linuxcenter_ru.png" , "http://www.linuxcenter.ru/" ] ,
  "couchsurfing mailer daemon" : [ "couchsurfing.png" , "http://www.couchsurfing.com/" ] ,
  "coppermine photo gallery" : [ "coppermine.png" , "http://coppermine-gallery.net/" ] ,
  "codestone mail control" : [ "codestone.png" , "http://www.codestone.ltd.uk/" ] ,
  "clever internet suite" : [ "cis.png" , "http://clevercomponents.com/products/inetsuite/suite.asp" ] ,
  "consultantplussender" : [ "consultant_ru.png" , "http://www.consultant.ru/" ] ,
  "clearcase automailer" : [ "clearcase.png" , "http://www-306.ibm.com/software/awdtools/clearcase/" ] ,
  "calcium web calendar" : [ "calcium.png" , "http://www.brownbearsw.com/calcium/" ] ,
  "crosspoint [openxp/" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "cpjnssmtpconnection" : [ "cpjnsmtpconnection.png" ] ,
  "cookie craft server" : [ "cookie_craft.png" , "http://www.cookie-craft.de/" ] ,
  "com.oreilly.servlet" : [ "servlets_com.png" , "http://www.servlets.com/cos/" ] ,
  "chorus by zerocode" : [ "zerocode.png" , "http://www.zerocode.com/" ] ,
  "catapulta.infomail" : [ "infomail.png" , "http://www.infomail.it/" ] ,
  "crosspoint/openxp" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "crosspoint/freexp" : [ "crosspoint_freexp.png" , "http://www.freexp.de/" ] ,
  "clear net webmail" : [ "clearnet.png" , "http://webmail.clear.net.nz/" ] ,
  "coremail webmail" : [ "coremail.png" , "http://www.mailtech.cn/" ] ,
  "copia emailfacts" : [ "copia_emailfacts.png" , "http://www.copia.com/e-mailfacts/" ] ,
  "cf_advancedemail" : [ "coldfusion.png" , "http://www.vandieten.net/jochem/coldfusion/customtags/advancedemail/" ] ,
  "catapulta.sender" : [ "infomail.png" , "http://www.infomail.it/" ] ,
  "cas genesisworld" : [ "genesis_world.png" , "http://www.cas.de/produkte/genesisWorld/" ] ,
  "cyrealis hermes" : [ "cyrealis.png" , "http://www.cyrealis.com/" ] ,
  "csmtpconnection" : [ "cpjnsmtpconnection.png" , "http://www.naughter.com/smtp.html" ] ,
  "crosspoint [xp2" : [ "crosspoint_xp2.png" , "http://xp2.de/" ] ,
  "coolblue-mailer" : [ "coolblue.png" ] ,
  "communigate pro" : [ "communigatepro.png" , "http://www.communigate.com/CommuniGatePro/" ] ,
  "cobian backup 9" : [ "cobianbackup9.png" , "http://www.cobian.se/" ] ,
  "cobian backup 8" : [ "cobianbackup8.png" , "http://www.cobian.se/" ] ,
  "cobian backup 7" : [ "cobianbackup7.png" , "http://www.cobian.se/" ] ,
  "cleancode.email" : [ "cleancode-email.png" , "http://www.cleancode.org/projects/email" ] ,
  "cenqua-crucible" : [ "crucible.png" , "http://www.cenqua.com/crucible" ] ,
  "cyberghost vpn" : [ "cyberghostvpn.png" , "http://www.cyberghostvpn.com/" ] ,
  "consol*cm-mail" : [ "consol_cm.png" , "http://www.consol.de/unternehmen/infomaterial/" ] ,
  "cogeco webmail" : [ "cogeco_ca.png" , "http://www.cogeco.ca/" ] ,
  "claros intouch" : [ "claros_intouch.png" , "http://www.claros.org/" ] ,
  "claris emailer" : [ "claris_emailer.png" , "http://www.claris.com/" ] ,
  "cappuccino crm" : [ "cappuccinosoft.png" , "http://www.cappuccinosoft.de/" ] ,
  "cad-kas mailer" : [ "cadkas_com.png" , "http://www.cadkas.com/" ] ,
  "c't-emailcheck" : [ "heise_security.png" , "http://www.heise.de/security/dienste/emailcheck/" ] ,
  "cu newsletter" : [ "cleverinternetsuite.png" , "http://www.clevercomponents.com/products/inetsuite/suite.asp" ] ,
  "cu mailsystem" : [ "computeruniverse.png" , "http://www.computeruniverse.net/" ] ,
  "ctm powermail" : [ "ctm_powermail.png" , "http://www.ctmdev.com/" ] ,
  "compost carma" : [ "compost_carma.png" , "http://www.compost.se/en/carma/" ] ,
  "codes-sources" : [ "code-source.png" ] ,
  "cobian backup" : [ "cobian.png" , "http://www.cobian.se/" ] ,
  "cdrwinkel.com" : [ "cdrwinkel.png" , "http://www.cdrwinkel.com/" ] ,
  "cash crusader" : [ "cashcrusader.png" , "http://cashcrusadersoftware.com/" ] ,
  "cards.mail.ru" : [ "mail_ru.png" , "http://www.mail.ru/" ] ,
  "custommailer" : [ "custommailer.png" , "http://www.wildcrest.com/" ] ,
  "copland mail" : [ "copland_udel_edu.png" , "http://copland.udel.edu/" ] ,
  "contactology" : [ "contactology.png" , "http://www.contactology.com/" ] ,
  "coldfusion 8" : [ "coldfusion8.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "coelnconcept" : [ "coelnconcept_de.png" , "http://www.coelnconcept.de/" ] ,
  "cmail writer" : [ "cmail_writer.png" , "http://mikilab.doshisha.ac.jp/~kawasaki/" ] ,
  "chatteremail" : [ "chatteremail.png" , "http://www.palm.com/us/software/chatteremail/" ] ,
  "centrum mail" : [ "centrum_cz.png" , "http://www.centrum.cz/" ] ,
  "center parcs" : [ "centerparcs_de.png" , "http://www.centerparcs.de/" ] ,
  "catchme@mail" : [ "catchmeatmail.png" , "http://www.canon-js.co.jp/english/products/webmail/catchmemail.html" ] ,
  "cashu system" : [ "cashu.png" , "http://www.cashu.com/" ] ,
  "carookee.com" : [ "carookee_com.png" , "http://www.carookee.com/" ] ,
  "com.zooplus" : [ "zooplus_de.png" , "http://www.zooplus.de/" ] ,
  "codeweavers" : [ "codeweavers.png" , "http://www.codeweavers.com/" ] ,
  "codeigniter" : [ "codeigniter.png" , "http://codeigniter.com/" ] ,
  "clickmailer" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
  "cb javamail" : [ "java.png" , "http://java.sun.com/products/javamail/" ] ,
  "crosspoint" : [ "crosspoint.png" , "http://www.crosspoint.de/" ] ,
  "createsend" : [ "createsend.png" , "http://www.createsend.com/" ] ,
  "cosmoshop/" : [ "cosmoshop.png" , "http://www.cosmoshop.de/" ] ,
  "contactlab" : [ "contactlab.png" , "http://www.contactlab.it/" ] ,
  "compuserve" : [ "compuserve.png" , "http://www.compuserve.com/" ] ,
  "coldfusion" : [ "coldfusion.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "cmmx01.dll" : [ "combit.png" , "http://www.combit.net/" ] ,
  "cloud nine" : [ "cloud9.png" , "http://www.cloudnine.se/" ] ,
  "clearquest" : [ "ibm.png" , "http://www-01.ibm.com/software/awdtools/clearquest/" ] ,
  "claws mail" : [ "claws-mail.png" , "http://www.claws-mail.org/" ] ,
  "chili!soft" : [ "chilisoft.png" , "http://www.chilisoft.com/" ] ,
  "cacert.org" : [ "cacert.png" , "http://www.cacert.org/" ] ,
  "ca_mailer/" : [ "ca_mailer.png" , "http://pro.channeladvisor.de/" ] ,
  "cvsmailer" : [ "cvsmailer.png" ] ,
  "consultes" : [ "consultes_it.png" , "http://www.consultes.it/" ] ,
  "clie mail" : [ "clie-mail.png" , "http://www.sony.jp/CLIE/" ] ,
  "citromail" : [ "citromail.png" ] ,
  "chordiant" : [ "chordiant.png" , "http://www.chordiant.com/" ] ,
  "cacaomail" : [ "cacaomail.png" , "http://ooyes.net/" ] ,
  "cubecart" : [ "cubecart.png" , "http://www.cubecart.com/" ] ,
  "cliffmoe" : [ "cliffmoe_com.png" , "http://www.cliffmoe.com/" ] ,
  "chauntry" : [ "chauntry.png" , "http://www.chauntry.com/" ] ,
  "chandler" : [ "chandler.png" , "http://chandlerproject.org/" ] ,
  "cgiemail" : [ "mit.png" , "http://web.mit.edu/wwwdev/cgiemail/" ] ,
  "cerberus" : [ "cerberus_helpdesk.png" , "http://www.cerberusweb.com/" ] ,
  "caramail" : [ "lycos-caramail.png" , "http://www.caramail.com/" ] ,
  "carteiro" : [ "carteiro.png" , "http://www.linkws.com/br/marketing/carteiro_apres.htm" ] ,
  "cabestan" : [ "cabestan.png" , "http://www.cabestan.com/" ] ,
  "cvsspam" : [ "cvs.png" ] ,
  "courier" : [ "courier.png" , "http://www.rosecitysoftware.com/courier/" ] ,
  "confixx" : [ "confixx.png" , "http://www.parallels.com/de/products/confixx/" ] ,
  "columba" : [ "columba.png" ] ,
  "cl-smtp" : [ "cl-smtp.png" , "http://common-lisp.net/project/cl-smtp/" ] ,
  "chilkat" : [ "chilkat.png" , "http://www.chilkatsoft.com/" ] ,
  "cbizone" : [ "cbizone.png" , "http://www.cbizsoft.com/" ] ,
  "cbfmail" : [ "cardboardfish_com.png" , "http://www.cardboardfish.com/" ] ,
  "calypso" : [ "calypso.png" , "http://www.rosecitysoftware.com/calypso/" ] ,
  "cakephp" : [ "cakephp.png" , "http://cakephp.org/" ] ,
  "cybozu" : [ "cybozu.png" , "http://www.cybozu.com/" ] ,
  "cwmail" : [ "netwinsite.png" , "http://netwinsite.com/cwmail/" ] ,
  "cmail1" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail2" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail3" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail4" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail5" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail6" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail7" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail8" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail9" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "clx.ru" : [ "clx_ru.png" , "http://www.clx.ru/" ] ,
  "chikka" : [ "chikka.png" , "http://www.chikka.com/txt2mail/" ] ,
  "chaos/" : [ "gnus.png" , "http://gnus.org/" ] ,
  "cpdev" : [ "cpdev.png" , "http://www.cpdev.co.uk/" ] ,
  "copix" : [ "copix.png" , "http://copix.org/" ] ,
  "cisco" : [ "cisco.png" , "http://www.cisco.com/" ] ,
  "camas" : [ "caudium.png" , "http://www.caudium.net/" ] ,
  "cacti" : [ "cacti.png" , "http://www.cacti.net/" ] ,
  "caff" : [ "caff.png" , "http://pgp-tools.alioth.debian.org/" ] ,
  "cms " : [ "hypernews.png" , "http://hypernews.slac.stanford.edu/" ] ,
  "cme-" : [ "infor.png" , "http://go.infor.com/inforcrm/" ] ,
}

==> icedove-dispmua_1.6.4.3.orig.tar.gz: icedove-dispmua-1.6.4.3/chrome/content/data-63.js <==
dispMUA.arDispMUAAllocation["c"] =
{
  "cart managment system at http://www.linuxcenter.ru" : [ "linuxcenter_ru.png" , "http://www.linuxcenter.ru/" ] ,
  "correo electrónico de internet de microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "cart managment system at http://linuxcenter.ru" : [ "linuxcenter_ru.png" , "http://www.linuxcenter.ru/" ] ,
  "couchsurfing mailer daemon" : [ "couchsurfing.png" , "http://www.couchsurfing.com/" ] ,
  "coppermine photo gallery" : [ "coppermine.png" , "http://coppermine-gallery.net/" ] ,
  "com.apple.wwdr.jmsmailer" : [ "apple.png" , "http://store.apple.com/" ] ,
  "codestone mail control" : [ "codestone.png" , "http://www.codestone.ltd.uk/" ] ,
  "clever internet suite" : [ "cis.png" , "http://clevercomponents.com/products/inetsuite/suite.asp" ] ,
  "consultantplussender" : [ "consultant_ru.png" , "http://www.consultant.ru/" ] ,
  "clearcase automailer" : [ "clearcase.png" , "http://www-306.ibm.com/software/awdtools/clearcase/" ] ,
  "calcium web calendar" : [ "calcium.png" , "http://www.brownbearsw.com/calcium/" ] ,
  "crosspoint [openxp/" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "cpjnssmtpconnection" : [ "cpjnsmtpconnection.png" ] ,
  "cookie craft server" : [ "cookie_craft.png" , "http://www.cookie-craft.de/" ] ,
  "com.oreilly.servlet" : [ "servlets_com.png" , "http://www.servlets.com/cos/" ] ,
  "cpjnsmtpconnection" : [ "cpjnsmtp.png" , "http://www.naughter.com/smtp.html" ] ,
  "contactoffice mail" : [ "contactoffice.png" , "http://www.contactoffice.com/" ] ,
  "chorus by zerocode" : [ "zerocode.png" , "http://www.zerocode.com/" ] ,
  "catapulta.infomail" : [ "infomail.png" , "http://www.infomail.it/" ] ,
  "crosspoint/openxp" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "crosspoint/freexp" : [ "crosspoint_freexp.png" , "http://www.freexp.de/" ] ,
  "clear net webmail" : [ "clearnet.png" , "http://webmail.clear.net.nz/" ] ,
  "coremail webmail" : [ "coremail.png" , "http://www.mailtech.cn/" ] ,
  "copia emailfacts" : [ "copia_emailfacts.png" , "http://www.copia.com/e-mailfacts/" ] ,
  "cf_advancedemail" : [ "coldfusion.png" , "http://www.vandieten.net/jochem/coldfusion/customtags/advancedemail/" ] ,
  "catapulta.sender" : [ "infomail.png" , "http://www.infomail.it/" ] ,
  "cas genesisworld" : [ "genesis_world.png" , "http://www.cas.de/produkte/genesisWorld/" ] ,
  "cadexpert.com.pl" : [ "cadexpert_com_pl.png" , "http://cadexpert.com.pl/" ] ,
  "cyrealis hermes" : [ "cyrealis.png" , "http://www.cyrealis.com/" ] ,
  "csmtpconnection" : [ "cpjnsmtpconnection.png" , "http://www.naughter.com/smtp.html" ] ,
  "crosspoint [xp2" : [ "crosspoint_xp2.png" , "http://xp2.de/" ] ,
  "coolblue-mailer" : [ "coolblue.png" ] ,
  "communigate pro" : [ "communigatepro.png" , "http://www.communigate.com/CommuniGatePro/" ] ,
  "cobian backup 9" : [ "cobianbackup9.png" , "http://www.cobian.se/" ] ,
  "cobian backup 8" : [ "cobianbackup8.png" , "http://www.cobian.se/" ] ,
  "cobian backup 7" : [ "cobianbackup7.png" , "http://www.cobian.se/" ] ,
  "cleancode.email" : [ "cleancode-email.png" , "http://www.cleancode.org/projects/email" ] ,
  "cenqua-crucible" : [ "crucible.png" , "http://www.cenqua.com/crucible" ] ,
  "cyberghost vpn" : [ "cyberghostvpn.png" , "http://www.cyberghostvpn.com/" ] ,
  "consol*cm-mail" : [ "consol_cm.png" , "http://www.consol.de/unternehmen/infomaterial/" ] ,
  "cogeco webmail" : [ "cogeco_ca.png" , "http://www.cogeco.ca/" ] ,
  "class smtpmail" : [ "emarsys.png" , "https://www.emarsys.com/" ] ,
  "claros intouch" : [ "claros_intouch.png" , "http://www.claros.org/" ] ,
  "claris emailer" : [ "claris_emailer.png" , "http://www.claris.com/" ] ,
  "cappuccino crm" : [ "cappuccinosoft.png" , "http://www.cappuccinosoft.de/" ] ,
  "cad-kas mailer" : [ "cadkas_com.png" , "http://www.cadkas.com/" ] ,
  "c't-emailcheck" : [ "heise_security.png" , "http://www.heise.de/security/dienste/emailcheck/" ] ,
  "cu newsletter" : [ "cleverinternetsuite.png" , "http://www.clevercomponents.com/products/inetsuite/suite.asp" ] ,
  "cu mailsystem" : [ "computeruniverse.png" , "http://www.computeruniverse.net/" ] ,
  "ctm powermail" : [ "ctm_powermail.png" , "http://www.ctmdev.com/" ] ,
  "compost carma" : [ "compost_carma.png" , "http://www.compost.se/en/carma/" ] ,
  "codes-sources" : [ "code-source.png" ] ,
  "cobian backup" : [ "cobian.png" , "http://www.cobian.se/" ] ,
  "chollian mail" : [ "chollian.png" , "http://www.chol.com/" ] ,
  "cdrwinkel.com" : [ "cdrwinkel.png" , "http://www.cdrwinkel.com/" ] ,
  "cash crusader" : [ "cashcrusader.png" , "http://cashcrusadersoftware.com/" ] ,
  "cards.mail.ru" : [ "mail_ru.png" , "http://www.mail.ru/" ] ,
  "custommailer" : [ "custommailer.png" , "http://www.wildcrest.com/" ] ,
  "copland mail" : [ "copland_udel_edu.png" , "http://copland.udel.edu/" ] ,
  "contactology" : [ "contactology.png" , "http://www.contactology.com/" ] ,
  "coldfusion 8" : [ "coldfusion8.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "coelnconcept" : [ "coelnconcept_de.png" , "http://www.coelnconcept.de/" ] ,
  "code igniter" : [ "code-igniter.png" , "http://codeigniter.com/" ] ,
  "cmail writer" : [ "cmail_writer.png" , "http://mikilab.doshisha.ac.jp/~kawasaki/" ] ,
  "chatteremail" : [ "chatteremail.png" , "http://www.palm.com/us/software/chatteremail/" ] ,
  "centrum mail" : [ "centrum_cz.png" , "http://www.centrum.cz/" ] ,
  "center parcs" : [ "centerparcs_de.png" , "http://www.centerparcs.de/" ] ,
  "catchme@mail" : [ "catchmeatmail.png" , "http://www.canon-js.co.jp/english/products/webmail/catchmemail.html" ] ,
  "cashu system" : [ "cashu.png" , "http://www.cashu.com/" ] ,
  "carookee.com" : [ "carookee_com.png" , "http://www.carookee.com/" ] ,
  "com.zooplus" : [ "zooplus_de.png" , "http://www.zooplus.de/" ] ,
  "codeweavers" : [ "codeweavers.png" , "http://www.codeweavers.com/" ] ,
  "codeigniter" : [ "codeigniter.png" , "http://codeigniter.com/" ] ,
  "clickmailer" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
  "cb javamail" : [ "java.png" , "http://java.sun.com/products/javamail/" ] ,
  "crosspoint" : [ "crosspoint.png" , "http://www.crosspoint.de/" ] ,
  "createsend" : [ "createsend.png" , "http://www.createsend.com/" ] ,
  "cosmoshop/" : [ "cosmoshop.png" , "http://www.cosmoshop.de/" ] ,
  "contactlab" : [ "contactlab.png" , "http://www.contactlab.it/" ] ,
  "compuserve" : [ "compuserve.png" , "http://www.compuserve.com/" ] ,
  "coldfusion" : [ "coldfusion.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "cmmx01.dll" : [ "combit.png" , "http://www.combit.net/" ] ,
  "cloud nine" : [ "cloud9.png" , "http://www.cloudnine.se/" ] ,
  "clearquest" : [ "ibm.png" , "http://www-01.ibm.com/software/awdtools/clearquest/" ] ,
  "claws mail" : [ "claws-mail.png" , "http://www.claws-mail.org/" ] ,
  "chili!soft" : [ "chilisoft.png" , "http://www.chilisoft.com/" ] ,
  "caprisonne" : [ "caprisonne.png" , "http://www.capri-sonne.de/" ] ,
  "cacert.org" : [ "cacert.png" , "http://www.cacert.org/" ] ,
  "ca_mailer/" : [ "ca_mailer.png" , "http://pro.channeladvisor.de/" ] ,
  "cvsmailer" : [ "cvsmailer.png" ] ,
  "consultes" : [ "consultes_it.png" , "http://www.consultes.it/" ] ,
  "clie mail" : [ "clie-mail.png" , "http://www.sony.jp/CLIE/" ] ,
  "citromail" : [ "citromail.png" ] ,
  "chordiant" : [ "chordiant.png" , "http://www.chordiant.com/" ] ,
  "cacmailer" : [ "commeaucinema.png" , "http://www.commeaucinema.com/" ] ,
  "cacaomail" : [ "cacaomail.png" , "http://ooyes.net/" ] ,
  "cubecart" : [ "cubecart.png" , "http://www.cubecart.com/" ] ,
  "cliffmoe" : [ "cliffmoe_com.png" , "http://www.cliffmoe.com/" ] ,
  "chauntry" : [ "chauntry.png" , "http://www.chauntry.com/" ] ,
  "chandler" : [ "chandler.png" , "http://chandlerproject.org/" ] ,
  "cgiemail" : [ "mit.png" , "http://web.mit.edu/wwwdev/cgiemail/" ] ,
  "cerberus" : [ "cerberus_helpdesk.png" , "http://www.cerberusweb.com/" ] ,
  "caramail" : [ "lycos-caramail.png" , "http://www.caramail.com/" ] ,
  "carteiro" : [ "carteiro.png" , "http://www.linkws.com/br/marketing/carteiro_apres.htm" ] ,
  "cabestan" : [ "cabestan.png" , "http://www.cabestan.com/" ] ,
  "cvsspam" : [ "cvs.png" ] ,
  "csg-net" : [ "csg-germering.png" , "http://intern.csg-germering.de/" ] ,
  "courier" : [ "courier.png" , "http://www.rosecitysoftware.com/courier/" ] ,
  "confixx" : [ "confixx.png" , "http://www.parallels.com/de/products/confixx/" ] ,
  "columba" : [ "columba.png" ] ,
  "clsimap" : [ "php.png" , "" ] ,
  "cl-smtp" : [ "cl-smtp.png" , "http://common-lisp.net/project/cl-smtp/" ] ,
  "chilkat" : [ "chilkat.png" , "http://www.chilkatsoft.com/" ] ,
  "cbizone" : [ "cbizone.png" , "http://www.cbizsoft.com/" ] ,
  "cbfmail" : [ "cardboardfish_com.png" , "http://www.cardboardfish.com/" ] ,
  "calypso" : [ "calypso.png" , "http://www.rosecitysoftware.com/calypso/" ] ,
  "cakephp" : [ "cakephp.png" , "http://cakephp.org/" ] ,
  "cybozu" : [ "cybozu.png" , "http://www.cybozu.com/" ] ,
  "cwmail" : [ "netwinsite.png" , "http://netwinsite.com/cwmail/" ] ,
  "cmail1" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "cmail2" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "cmail3" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "cmail4" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "cmail5" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "cmail6" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "cmail7" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "cmail8" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "cmail9" : [ "campaignmonitor.png" , "http://www.campaignmonitor.com/" ] ,
  "clx.ru" : [ "clx_ru.png" , "http://www.clx.ru/" ] ,
  "chikka" : [ "chikka.png" , "http://www.chikka.com/txt2mail/" ] ,
  "chaos/" : [ "gnus.png" , "http://gnus.org/" ] ,
  "ccmail" : [ "cicoandcico.png" , "http://www.cicoandcico.com/ccmail-10/" ] ,
  "cpdev" : [ "cpdev.png" , "http://www.cpdev.co.uk/" ] ,
  "copix" : [ "copix.png" , "http://copix.org/" ] ,
  "cisco" : [ "cisco.png" , "http://www.cisco.com/" ] ,
  "camas" : [ "caudium.png" , "http://www.caudium.net/" ] ,
  "cacti" : [ "cacti.png" , "http://www.cacti.net/" ] ,
  "caff" : [ "caff.png" , "http://pgp-tools.alioth.debian.org/" ] ,
  "com " : [ "wincom.png" , "" ] ,
  "cms " : [ "hypernews.png" , "http://hypernews.slac.stanford.edu/" ] ,
  "cme-" : [ "infor.png" , "http://go.infor.com/inforcrm/" ] ,
}
